OrderBookLevel class

Order book price level.

Constructors

OrderBookLevel({required double price, required double quantity})
const
OrderBookLevel.fromList(List data)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
price double
final
quantity double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value double
Total value at this level
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toList() List<String>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited