AggTrade class
Aggregated trade data.
Constructors
Properties
- aggTradeId → int
-
final
- firstTradeId → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isBestMatch → bool
-
final
- isBuy → bool
-
Is this a buy order?
no setter
- isBuyerMaker → bool
-
final
- lastTradeId → int
-
final
- price → double
-
final
- quantity → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime
-
final
- value → double
-
Trade value (price * quantity)
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited